## cdist-type__package_rubygem(7)

### Chase Allen James

`<nx-cdist@nu-ex.com>`

## 1. NAME

cdist-type__package_rubygem - Manage rubygem packages

## 2. DESCRIPTION

Rubygems is the default package management system for the Ruby programming language.

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
state
  Either "present" or "absent", defaults to "present"

## 5. EXAMPLES

    # Ensure sinatra is installed
    __package_rubygem sinatra --state present

    # Remove package
    __package_rubygem rails --state absent

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__package(7)

## 7. COPYING

Copyright (C) 2011 Chase Allen James. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).